package org.wbconfig;

import java.util.Collections;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.List;
import java.util.ResourceBundle;

import org.apache.commons.collections.FastArrayList;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.swt.SWT;
import org.wbconfig.action.ActionMap;
import org.wbconfig.action.file.OpenAction;
import org.wbconfig.action.file.PreviewAction;
import org.wbconfig.action.file.QuitAction;
import org.wbconfig.action.file.RevertAction;
import org.wbconfig.action.file.SaveAction;
import org.wbconfig.action.file.SaveAsAction;
import org.wbconfig.action.help.AboutAction;
import org.wbconfig.action.help.LaunchURLAction;
import org.wbconfig.resource.ResourceManager;

/**
 * AppMenuManager.java
 * @author Xavier Cho
 * @version $Revision: 1.7 $ $Date: 2004/01/31 06:07:53 $
 */
public class AppMenuManager extends MenuManager {
    private ActionMap actions;

    private WBConfig application;
    private ResourceManager resources;

    public AppMenuManager(final WBConfig application) {
        if (application == null) {
            SWT.error(SWT.ERROR_NULL_ARGUMENT);
        }

        this.application = application;
        this.actions = application.getActionMap();
        this.resources = ResourceManager.getInstance();

        initialize();
    }

    protected void initialize() {
        add(createFileMenu());
        add(createHelpMenu());
    }

    protected MenuManager createFileMenu() {
        String name = resources.getString("menu.file");
        MenuManager manager = new MenuManager(name);

        manager.add(actions.get(OpenAction.class));
        manager.add(actions.get(SaveAction.class));
        manager.add(actions.get(SaveAsAction.class));
        manager.add(actions.get(RevertAction.class));
        manager.add(new Separator());
        manager.add(actions.get(PreviewAction.class));
        //manager.add(new Separator());
        //manager.add(actions.get(SettingsAction.class));
        manager.add(new Separator());
        manager.add(actions.get(QuitAction.class));

        return manager;
    }

    protected MenuManager createHelpMenu() {
        String name = resources.getString("menu.help");
        MenuManager manager = new MenuManager(name);

        manager.add(createResourcesMenu());
        manager.add(new Separator());
        manager.add(actions.get(AboutAction.class));
        return manager;
    }

    protected MenuManager createResourcesMenu() {
        String name = resources.getString("menu.resources");
        MenuManager manager = new MenuManager(name);

        ResourceBundle bundle =
            ResourceBundle.getBundle("org.wbconfig.resource.WebResources");

        List list = new FastArrayList(20);

        Enumeration enum = bundle.getKeys();

        while (enum.hasMoreElements()) {
            String key = (String) enum.nextElement();
            list.add(key);
        }

        Collections.sort(list);

        Iterator it = list.iterator();
        while (it.hasNext()) {
            String key = (String) it.next();
            String[] values = bundle.getString(key).split(",");

            manager.add(new LaunchURLAction(application, values[0], values[1]));
        }

        return manager;
    }
}
