package org.wbconfig.action;

import java.util.HashMap;
import java.util.Map;

import org.apache.commons.lang.NullArgumentException;
import org.eclipse.swt.SWT;

/**
 * ActionMap.java
 * @author Xavier Cho
 * @version $Revision: 1.2 $ $Date: 2004/01/24 06:37:48 $
 */
public class ActionMap {
    private Map actions;
    private ActionMap parent;

    public ActionMap() {
        this(null);
    }

    public ActionMap(final ActionMap parent) {
        this.actions = new HashMap(20);
        this.parent = parent;
    }

    public BaseAction get(final Class cls) {
        if (cls == null) {
            throw new NullArgumentException("cls");
        }

        return get(cls.getName());
    }

    public BaseAction get(final String name) {
        if (name == null) {
            throw new NullArgumentException("name");
        }

        BaseAction action = (BaseAction) actions.get(name);

        if (action == null && parent != null) {
            action = parent.get(name);
        }

        return action;
    }

    public void put(final BaseAction action) {
        if (action == null) {
            SWT.error(SWT.ERROR_NULL_ARGUMENT);
        }

        actions.put(action.getId(), action);
    }

    public int getSize() {
        return actions.size();
    }

    public ActionMap getParent() {
        return parent;
    }

    public void setParent(final ActionMap parent) {
        this.parent = parent;
    }
}