package org.wbconfig.action;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.swt.SWT;
import org.wbconfig.WBConfig;
import org.wbconfig.resource.ResourceManager;

/**
 * BaseAction.java
 * @author Xavier Cho
 * @version $Revision: 1.1 $ $Date: 2003/12/31 09:29:54 $
 */
public abstract class BaseAction extends Action {
    public static final String ACCELERATOR = "accelerator";

    private WBConfig application;

    private BaseAction() {
    }

    public BaseAction(final WBConfig application) {
        this(application, IAction.AS_UNSPECIFIED);
    }

    public BaseAction(final WBConfig application, final int style) {
        super(null, style);

        if (application == null) {
            SWT.error(SWT.ERROR_NULL_ARGUMENT);
        }

        this.application = application;

        ResourceManager resources = ResourceManager.getInstance();

        String prefix = getId().concat(".");

        setText(resources.getString(prefix.concat(TEXT)));
        setDescription(resources.getString(prefix.concat(DESCRIPTION)));
        setImageDescriptor(resources.getImageDescriptor(prefix.concat(IMAGE)));
        setToolTipText(getDescription());

        String accelerator = resources.getString(prefix.concat(ACCELERATOR));
        if (accelerator != null) {
            setAccelerator(Action.convertAccelerator(accelerator));
        }
    }

    protected WBConfig getApplication() {
        return application;
    }

    public String getId() {
        return getClass().getName();
    }
}