package org.wbconfig.action.file;

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.jface.preference.IPreferencePage;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.JFacePreferences;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.swt.widgets.Shell;
import org.wbconfig.WBConfig;
import org.wbconfig.action.BaseAction;
import org.wbconfig.preference.ConfigPreferenceStore;
import org.wbconfig.resource.ResourceManager;
import org.wbconfig.util.ExceptionHandler;
import org.wbconfig.widget.ConfigurationTab;

/**
 * OpenAction.java
 *
 * @author Xavier Cho
 * @version $Revision: 1.5 $ $Date: 2004/01/24 14:25:14 $
 */
public class OpenAction extends BaseAction {
    private static final String[] FILTER_EXTENSIONS = new String[] {"*.cfg"};

    public OpenAction(final WBConfig application) {
        super(application);
    }

    /**
     * @see org.eclipse.jface.action.IAction#runWithEvent(org.eclipse.swt.widgets.Event)
     */
    public void runWithEvent(final Event event) {
        Shell parent = getApplication().getShell();

        boolean isDirty = ConfigPreferenceStore.getInstance().needsSaving();

        if (isDirty) {
            ResourceManager resources = ResourceManager.getInstance();
            String title = resources.getString("dialog.title.confirm");
            String message =
                resources.getString("message.open.discard.changes");

            if (!MessageDialog.openConfirm(parent, title, message)) {
                return;
            }
        }

        IPreferenceStore preferences = JFacePreferences.getPreferenceStore();
        String path = preferences.getString("open.path");

        FileDialog dialog = new FileDialog(parent, SWT.OPEN);
        dialog.setFilterPath(path);
        dialog.setFilterExtensions(FILTER_EXTENSIONS);

        String fileName = dialog.open();

        path = dialog.getFilterPath();
        preferences.setValue("open.path", path);

        if (fileName != null) {
            try {
                getApplication().run(true, true, new FileWorker(fileName));
            } catch (Exception e) {
                ResourceManager resources = ResourceManager.getInstance();
                String msg = resources.getString("error.message.open");
                ExceptionHandler.handleException(msg, e);
            }
        }
    }

    private final class FileWorker implements IRunnableWithProgress {
        private String fileName;

        private FileWorker(final String fileName) {
            this.fileName = fileName;
        }

        /**
         * @see org.eclipse.jface.operation.IRunnableWithProgress#run(org.eclipse.core.runtime.IProgressMonitor)
         */
        public void run(final IProgressMonitor monitor)
            throws InvocationTargetException, InterruptedException {

            ResourceManager resources = ResourceManager.getInstance();

            monitor.beginTask(
                resources.getString("message.open.progress"),
                IProgressMonitor.UNKNOWN);

            try {
                ConfigPreferenceStore preferences =
                    ConfigPreferenceStore.getInstance();

                preferences.setFilename(fileName);
                preferences.load();

                Display display = Display.getDefault();
                display.syncExec(new Runnable() {
                    public void run() {
                        ResourceManager resources =
                            ResourceManager.getInstance();

                        StringBuffer buffer = new StringBuffer();
                        buffer.append(resources.getString("application.title"));
                        buffer.append(" - ");
                        buffer.append(fileName);

                        String title = buffer.toString();

                        WBConfig application = getApplication();
                        application.getShell().setText(title);

                        IPreferencePage[] pages =
                            application.getPreferencePages();

                        int size = pages.length;
                        for (int i = 0; i < size; i++) {
                            ConfigurationTab tab = (ConfigurationTab) pages[i];
                            tab.performLoad();
                        }

                        application.updateButtons();
                    }
                });
            } catch (IOException e) {
                String msg = resources.getString("error.message.open");
                ExceptionHandler.handleException(msg, e);
            } finally {
                monitor.done();
            }
        }
    }
}