package org.wbconfig.action.file;

import java.io.IOException;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.preference.IPreferencePage;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Shell;
import org.wbconfig.WBConfig;
import org.wbconfig.action.BaseAction;
import org.wbconfig.preference.ConfigPreferenceStore;
import org.wbconfig.resource.ResourceManager;
import org.wbconfig.util.ExceptionHandler;
import org.wbconfig.widget.ConfigurationTab;

/**
 * RevertAction.java
 * @author Xavier Cho
 * @version $Revision: 1.2 $ $Date: 2004/01/24 14:25:14 $
 */
public class RevertAction extends BaseAction {

    public RevertAction(final WBConfig application) {
        super(application);
    }

    /**
     * @see org.eclipse.jface.action.IAction#runWithEvent(org.eclipse.swt.widgets.Event)
     */
    public void runWithEvent(final Event event) {
        WBConfig application = getApplication();
        ResourceManager resources = ResourceManager.getInstance();
        ConfigPreferenceStore preferences = ConfigPreferenceStore.getInstance();

        boolean isDirty = preferences.needsSaving();

        if (isDirty) {
            Shell parent = application.getShell();
            String title = resources.getString("dialog.title.confirm");
            String message =
                resources.getString("message.revert.discard.changes");

            if (!MessageDialog.openConfirm(parent, title, message)) {
                return;
            }
        }

        try {
            preferences.load();

            IPreferencePage[] pages =
                application.getPreferencePages();

            int size = pages.length;
            for (int i = 0; i < size; i++) {
                ConfigurationTab tab = (ConfigurationTab) pages[i];
                tab.performLoad();
            }

            application.updateButtons();
        } catch (IOException e) {
            String msg = resources.getString("error.message.open");
            ExceptionHandler.handleException(msg, e);
        }
    }
}
