package org.wbconfig.action.file;

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.wbconfig.WBConfig;
import org.wbconfig.action.BaseAction;
import org.wbconfig.preference.ConfigPreferenceStore;
import org.wbconfig.resource.ResourceManager;
import org.wbconfig.util.ExceptionHandler;

/**
 * SaveAction.java
 * @author Xavier Cho
 * @version $Revision: 1.3 $ $Date: 2004/01/18 11:51:28 $
 */
public class SaveAction extends BaseAction {

    public SaveAction(final WBConfig application) {
        super(application);
    }

    /**
     * @see org.eclipse.jface.action.IAction#runWithEvent(org.eclipse.swt.widgets.Event)
     */
    public void runWithEvent(final Event event) {
        try {
            getApplication().run(true, true, new FileWorker());
        } catch (Exception e) {
            ResourceManager resources = ResourceManager.getInstance();
            String msg = resources.getString("error.message.save");
            ExceptionHandler.handleException(msg, e);
        }
    }

    private class FileWorker implements IRunnableWithProgress {
        /**
         * @see org.eclipse.jface.operation.IRunnableWithProgress#run(org.eclipse.core.runtime.IProgressMonitor)
         */
        public void run(final IProgressMonitor monitor)
        throws InvocationTargetException, InterruptedException {

            ResourceManager resources = ResourceManager.getInstance();

            monitor.beginTask(
                    resources.getString("message.open.progress"),
                    IProgressMonitor.UNKNOWN);

            try {
                ConfigPreferenceStore preferences =
                    ConfigPreferenceStore.getInstance();

                preferences.save();

                Display display = Display.getDefault();
                display.syncExec(new Runnable() {
                    public void run() {
                        getApplication().updateButtons();
                    }
                });
            } catch (IOException e) {
                String msg = resources.getString("error.message.save");
                ExceptionHandler.handleException(msg, e);
            } finally {
                monitor.done();
            }
        }
    }
}
