package org.wbconfig.action.file;

import java.io.File;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.JFacePreferences;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.swt.widgets.Shell;
import org.wbconfig.WBConfig;
import org.wbconfig.action.BaseAction;
import org.wbconfig.preference.ConfigPreferenceStore;
import org.wbconfig.resource.ResourceManager;
import org.wbconfig.util.ExceptionHandler;

/**
 * SaveAsAction.java
 *
 * @author Xavier Cho
 * @version $Revision: 1.4 $ $Date: 2004/01/19 02:11:57 $
 */
public class SaveAsAction extends BaseAction {
    private static final String[] FILTER_EXTENSIONS = new String[] {"*.cfg"};

    public SaveAsAction(final WBConfig application) {
        super(application);
    }

    /**
     * @see org.eclipse.jface.action.IAction#runWithEvent(org.eclipse.swt.widgets.Event)
     */
    public void runWithEvent(final Event event) {
        Shell parent = getApplication().getShell();

        IPreferenceStore preferences = JFacePreferences.getPreferenceStore();
        String path = preferences.getString("open.path");

        FileDialog dialog = new FileDialog(parent, SWT.SAVE);
        dialog.setFilterPath(path);
        dialog.setFilterExtensions(FILTER_EXTENSIONS);

        String fileName = dialog.open();

        path = dialog.getFilterPath();
        preferences.setValue("open.path", path);

        if (fileName != null) {
            File file = new File(fileName);

            if (file.exists()) {
                ResourceManager resources = ResourceManager.getInstance();
                String title = resources.getString("dialog.title.confirm");
                String message =
                    resources.getString("message.confirm.overwrite");

                if (!MessageDialog.openConfirm(parent, title, message)) {
                    return;
                }
            }

            try {
                getApplication().run(true, true, new FileWorker(fileName));
            } catch (Exception e) {
                ResourceManager resources = ResourceManager.getInstance();
                String msg = resources.getString("error.message.save");
                ExceptionHandler.handleException(msg, e);
            }
        }
    }

    private final class FileWorker implements IRunnableWithProgress {
        private String fileName;

        private FileWorker(final String fileName) {
            this.fileName = fileName;
        }

        /**
         * @see org.eclipse.jface.operation.IRunnableWithProgress#run(org.eclipse.core.runtime.IProgressMonitor)
         */
        public void run(final IProgressMonitor monitor)
            throws InvocationTargetException, InterruptedException {

            ResourceManager resources = ResourceManager.getInstance();

            monitor.beginTask(
                resources.getString("message.save.progress"),
                IProgressMonitor.UNKNOWN);

            try {
                ConfigPreferenceStore preferences =
                    ConfigPreferenceStore.getInstance();

                preferences.setFilename(fileName);
                preferences.save();

                Display display = Display.getDefault();
                display.syncExec(new Runnable() {
                    public void run() {
                        ResourceManager resources =
                            ResourceManager.getInstance();

                        StringBuffer buffer = new StringBuffer();
                        buffer.append(resources.getString("application.title"));
                        buffer.append(" - ");
                        buffer.append(fileName);

                        String title = buffer.toString();
                        getApplication().getShell().setText(title);
                    }
                });
            } catch (IOException e) {
                String msg = resources.getString("error.message.save");
                ExceptionHandler.handleException(msg, e);
            } finally {
                monitor.done();
            }
        }
    }
}
