package org.wbconfig.action.help;

import org.apache.commons.lang.NullArgumentException;
import org.eclipse.jface.action.Action;
import org.eclipse.swt.SWT;
import org.eclipse.swt.program.Program;
import org.eclipse.swt.widgets.Event;
import org.wbconfig.WBConfig;

/**
 * LaunchURLAction.java
 * @author Xavier Cho
 * @version $Revision: 1.1 $ $Date: 2004/01/24 14:25:14 $
 */
public class LaunchURLAction extends Action {
    private static final String[] BROWSERS =
        new String[] {"www-browser", "galeon", "epiphany", "mozilla"};

    private static String browser;
    private String url;

    public LaunchURLAction(
        final WBConfig application,
        final String url,
        final String name) {

        if (url == null) {
            throw new NullArgumentException("url");
        }

        if (name == null) {
            throw new NullArgumentException("name");
        }

        this.url = url;

        setText(name);
    }

    /**
     * @return
     */
    public String getUrl() {
        return url;
    }
    /**
     * @param string
     */
    public void setUrl(final String string) {
        url = string;
    }

    /**
     * @see org.eclipse.jface.action.IAction#runWithEvent(org.eclipse.swt.widgets.Event)
     */
    public void runWithEvent(final Event event) {
        String platform = SWT.getPlatform();

        if (platform.equalsIgnoreCase("win32")
            || platform.equalsIgnoreCase("carbon")) {
            Program.launch(url);
        } else {
            if (browser == null) {
                synchronized (LaunchURLAction.class) {
                    int size = BROWSERS.length;
                    for (int i = 0; i < size; i++) {
                        if (Program.launch(BROWSERS[i] + " " + url)) {
                            browser = BROWSERS[i];
                            break;
                        }
                    }
                }
            } else {
                Program.launch(browser + " " + url);
            }
        }
    }
}
