package org.wbconfig.util;

import java.util.Collection;
import java.util.Iterator;
import java.util.Map;

import org.apache.commons.collections.FastHashMap;
import org.apache.commons.collections.MultiHashMap;
import org.apache.commons.collections.MultiMap;
import org.apache.commons.lang.NullArgumentException;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.regexp.RE;

/**
 * ConfigLineParser.java
 *
 * @author Xavier Cho
 * @version $Revision: 1.2 $ $Date: 2004/01/19 02:11:57 $
 */
public final class ConfigLineParser {
    private static final String PATTERN = "^\\.([a-zA-Z]+)\\s*(\\w*)";
    private static final String[] KNOWN_BOOLEAN_KEYS =
        new String[] {"envmap", "multipass", "smoke", "slip", "hud"};

    private static Log log = LogFactory.getLog(ConfigLineParser.class);

    private MultiMap properties;
    private RE pattern;

    public ConfigLineParser() {
        this.pattern = new RE(PATTERN);
        this.properties = new MultiHashMap(100);
    }

    public void add(final String line) {
        if (line == null) {
            throw new NullArgumentException("line");
        }

        if (log.isDebugEnabled()) {
            log.debug("Processing line : " + line);
        }

        if (pattern.match(line)) {
            String key = null;
            String v = pattern.getParen(2);

            Object value = null;

            if (StringUtils.isEmpty(v)) {
                key = pattern.getParen(1).toLowerCase() + ".toggle";
                value = Boolean.TRUE;
            } else {
                key = pattern.getParen(1).toLowerCase();

                if (isBooleanKey(key)) {
                    key += ".boolean";
                    if (v.trim().equals("1")) {
                        value = Boolean.TRUE;
                    } else {
                        value = Boolean.FALSE;
                    }
                } else {
                    if (StringUtils.isNumeric(v)) {
                        value = new Integer(v);
                    } else {
                        value = v;
                    }
                }
            }

            if (key != null && value != null) {
                if (log.isDebugEnabled()) {
                    log.debug(" - key : " + key);
                    log.debug(" - value : " + value);
                }

                synchronized (properties) {
                    properties.put(key, value);
                }
            }
        } else {
            if (log.isDebugEnabled()) {
                log.debug("Unknown line : " + line);
            }
        }
    }

    private static boolean isBooleanKey(final String key) {
        int size = KNOWN_BOOLEAN_KEYS.length;
        for (int i = 0; i < size; i++) {
            if (key.equals(KNOWN_BOOLEAN_KEYS[i])) {
                return true;
            }
        }

        return false;
    }

    public Map getPropertiesMap() {
        Map map = new FastHashMap(200);

        synchronized (properties) {
            Iterator i = properties.keySet().iterator();
            while (i.hasNext()) {
                Object key = i.next();
                Collection values = (Collection) properties.get(key);

                if (values.size() == 1) {
                    Object value = values.iterator().next();
                    map.put(key, value);
                } else {
                    Iterator i2 = values.iterator();
                    while (i2.hasNext()) {
                        Object v = i2.next();
                        map.put(key + "." + v, Boolean.TRUE);
                    }
                }
            }
        }

        return map;
    }
}
