package org.wbconfig.util;

import java.io.PrintWriter;
import java.io.StringWriter;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.MultiStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.widgets.Display;
import org.wbconfig.resource.ResourceManager;

/**
 * ExceptionHandler.java
 *
 * @author Xavier Cho
 * @version $Revision: 1.4 $ $Date: 2004/01/24 14:25:14 $
 */
public class ExceptionHandler implements Window.IExceptionHandler {
    private static Log log = LogFactory.getLog(ExceptionHandler.class);

    public void handleException(final Throwable t) {
        handleException(null, t);
    }

    public static void handleException(final String msg, final Throwable t) {
        ResourceManager resources = ResourceManager.getInstance();
        String message = msg;

        try {
            if (message == null) {
                message = resources.getString("error.message.unknown");
            }
        } catch (Throwable th) {
            message = "Unhandled exception has occurred.";
        }

        try {
            StringWriter writer = new StringWriter();
            PrintWriter printer = new PrintWriter(writer);

            t.printStackTrace(printer);

            Status status =
                new Status(
                    Status.ERROR,
                    ExceptionHandler.class.getName(),
                    Status.OK,
                    t.toString(),
                    t);

            MultiStatus multiStatus =
                new MultiStatus(
                    ExceptionHandler.class.getName(),
                    Status.OK,
                    message,
                    t);
            multiStatus.add(status);

            Display display = Display.getDefault();
            String title = resources.getString("dialog.title.error");

            if (display == null) {
                ErrorDialog.openError(null, title, message, multiStatus);
            } else {
                display.syncExec(new DialogHelper(title, message, status));
            }
        } catch (Throwable th) {
            log.warn("Unable to open error dialog : " + th.getMessage(), th);
        }

        if (log.isErrorEnabled()) {
            log.error(msg, t);
        }
    }

    private static final class DialogHelper implements Runnable {
        private IStatus status;
        private String title;
        private String message;

        private DialogHelper(
            final String title,
            final String message,
            final IStatus status) {
            this.title = title;
            this.message = message;
            this.status = status;
        }

        /**
         * @see java.lang.Runnable#run()
         */
        public void run() {
            ErrorDialog.openError(null, title, message, status);
        }
    }
}
