package org.wbconfig.util;

import java.io.File;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * SpecialFolders.java
 * @author Xavier Cho
 * @version $Revision: 1.1 $ $Date: 2003/12/31 09:29:55 $
 */
public final class SpecialFolders {
    private static Log log = LogFactory.getLog(SpecialFolders.class);

    private static String applicationHome;
    private static String preferenceFilePath;

    private SpecialFolders() {
    }

    private static void checkDirectory(final String path) {
        File dir = new File(path);
        if (!dir.exists()) {
            if (log.isInfoEnabled()) {
                log.info("Creating directory " + dir.getAbsolutePath());
            }
            dir.mkdirs();
        }
    }

    public static String getUserHomeDirectory() {
        return System.getProperty("user.home");
    }

    public static String getWorkDirectory() {
        return System.getProperty("user.dir");
    }

    public static String getApplicationHomeDirectory() {
        if (applicationHome == null) {
            synchronized (SpecialFolders.class) {
                StringBuffer buffer = new StringBuffer();
                buffer.append(getUserHomeDirectory());
                buffer.append(File.separator);
                buffer.append(".wbconfig");

                applicationHome = buffer.toString();

                if (log.isInfoEnabled()) {
                    log.info("Application home dir - " + applicationHome);
                }

                checkDirectory(applicationHome);
            }
        }

        return applicationHome;
    }

    public static String getPreferenceFilePath() {
        if (preferenceFilePath == null) {
            synchronized (SpecialFolders.class) {
                StringBuffer buffer = new StringBuffer();
                buffer.append(getApplicationHomeDirectory());
                buffer.append(File.separator);
                buffer.append("preferences.properties");

                preferenceFilePath = buffer.toString();

                if (log.isInfoEnabled()) {
                    log.info("Preference file path - " + preferenceFilePath);
                }
            }
        }

        return preferenceFilePath;
    }
}