package org.wbconfig.widget;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import org.apache.commons.lang.NullArgumentException;
import org.eclipse.jface.preference.FieldEditor;
import org.eclipse.jface.preference.IPreferencePageContainer;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.jface.util.PropertyChangeEvent;

/**
 * ConfigurationTab.java
 *
 * @author Xavier Cho
 * @version $Revision: 1.5 $ $Date: 2004/01/24 14:25:14 $
 */
public abstract class ConfigurationTab
    extends PreferencePage
    implements IPropertyChangeListener {
    private Collection fieldEditors;

    public ConfigurationTab() {
        this(null, null);
    }

    /**
     * @param title
     */
    public ConfigurationTab(final String title) {
        this(title, null);
    }

    /**
     * @param title
     * @param image
     */
    public ConfigurationTab(final String title, final ImageDescriptor image) {
        super(title, image);

        this.fieldEditors = new ArrayList(30);
        this.noDefaultAndApplyButton();
    }

    protected void addField(final FieldEditor editor) {
        if (editor == null) {
            throw new NullArgumentException("editor");
        }

        editor.setPreferencePage(this);
        editor.setPropertyChangeListener(this);
        editor.load();

        if (!fieldEditors.contains(editor)) {
            fieldEditors.add(editor);
        }
    }

    /**
     * @see org.eclipse.jface.preference.PreferencePage#setPreferenceStore(org.eclipse.jface.preference.IPreferenceStore)
     */
    public void setPreferenceStore(final IPreferenceStore preferences) {
        super.setPreferenceStore(preferences);

        if (preferences != null) {
            Iterator it = fieldEditors.iterator();
            while (it.hasNext()) {
                FieldEditor editor = (FieldEditor) it.next();
                editor.setPreferenceStore(preferences);
            }

            performLoad();
        }
    }

    /**
     * @see org.eclipse.jface.preference.PreferencePage#performApply()
     */
    protected void performApply() {
        Iterator it = fieldEditors.iterator();
        while (it.hasNext()) {
            FieldEditor editor = (FieldEditor) it.next();
            if (editor.isValid()) {
                editor.store();
            }
        }
    }

    /**
     * @see org.eclipse.jface.preference.PreferencePage#performDefaults()
     */
    public void performDefaults() {
        Iterator it = fieldEditors.iterator();
        while (it.hasNext()) {
            FieldEditor editor = (FieldEditor) it.next();
            editor.loadDefault();
        }
    }

    public void performLoad() {
        Iterator it = fieldEditors.iterator();
        while (it.hasNext()) {
            FieldEditor editor = (FieldEditor) it.next();
            editor.load();
        }
    }

    /**
     * @see org.eclipse.jface.preference.IPreferencePage#performOk()
     */
    public boolean performOk() {
        performApply();
        return false;
    }

    /**
     * @see org.eclipse.jface.preference.IPreferencePage#isValid()
     */
    public boolean isValid() {
        Iterator it = fieldEditors.iterator();
        while (it.hasNext()) {
            FieldEditor editor = (FieldEditor) it.next();
            if (!editor.isValid()) {
                return false;
            }
        }

        return true;
    }

    /**
     * @see org.eclipse.jface.preference.IPreferencePage#setContainer(org.eclipse.jface.preference.IPreferencePageContainer)
     */
    public void setContainer(final IPreferencePageContainer container) {
        super.setContainer(container);

        if (container != null) {
            setPreferenceStore(container.getPreferenceStore());
        }
    }

    /**
     * @see org.eclipse.jface.util.IPropertyChangeListener#propertyChange(org.eclipse.jface.util.PropertyChangeEvent)
     */
    public void propertyChange(final PropertyChangeEvent event) {
        String property = event.getProperty();

        IPreferencePageContainer container = getContainer();
        if (container != null) {
            if (FieldEditor.IS_VALID.equals(property)) {
                container.updateMessage();
            } else if (FieldEditor.VALUE.equals(property)) {
                performApply();
                container.updateButtons();
            }
        }
    }
}