package org.wbconfig.widget;

import java.util.Collection;
import java.util.Iterator;

import org.apache.commons.collections.FastArrayList;
import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.FieldEditor;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.RadioGroupFieldEditor;
import org.eclipse.jface.preference.ScaleFieldEditor;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.wbconfig.resource.ResourceManager;

/**
 * DisplayTab.java
 *
 * @author Xavier Cho
 * @version $Revision: 1.6 $ $Date: 2004/01/25 08:25:26 $
 */
public class DisplayTab extends ConfigurationTab {
    private Button radioPresetHigh;
    private Button radioPresetMedium;
    private Button radioPresetLow;
    private Button radioPresetCustom;

    private static final int PRESET_HIGH = 0;
    private static final int PRESET_MEDIUM = 1;
    private static final int PRESET_LOW = 2;

    private static final int[] PRESET_VAR = new int[] {8500, 5666, 4250};
    private static final int[] PRESET_LOD = new int[] {500, 0, 0};
    private static final int[] PRESET_DETAIL = new int[] {2, 1, 0};
    private static final int[] PRESET_TEX = new int[] {256, 128, 64};
    private static final int[] PRESET_TEXSIZE = new int[] {0, 1, 2};
    private static final int[] PRESET_RENDER = new int[] {15000, 8000, 5000};
    private static final int[] PRESET_CLUTTER = new int[] {8000, 6000, 3000};
    private static final boolean[] PRESET_EMAP =
        new boolean[] {true, true, false};
    private static final int[] PRESET_WATER = new int[] {0, 1, 2};
    private static final int[] PRESET_SHADOW = new int[] {2, 0, 0};

    private Collection presetEditors;

    public DisplayTab() {
    }

    /**
     * @param title
     */
    public DisplayTab(final String title) {
        super(title);
    }

    /**
     * @param title
     * @param image
     */
    public DisplayTab(final String title, final ImageDescriptor image) {
        super(title, image);
    }

    /**
     * @see org.eclipse.jface.preference.PreferencePage#createContents(org.eclipse.swt.widgets.Composite)
     */
    protected Control createContents(final Composite parent) {
        Composite panel = new Composite(parent, SWT.NULL);

        GridLayout layout = new GridLayout(1, false);
        layout.marginWidth = 10;
        layout.marginHeight = 10;

        panel.setLayout(layout);

        ResourceManager resources = ResourceManager.getInstance();

        Group group = new Group(panel, SWT.NULL);
        group.setText(resources.getString("group.display"));
        group.setLayoutData(new GridData(GridData.FILL_BOTH));

        Label label = new Label(group, SWT.NULL);
        label.setText(resources.getString("label.preset"));

        GridData data = new GridData();
        label.setLayoutData(data);

        Composite radioPanel = new Composite(group, SWT.NULL);

        GridLayout layout2 = new GridLayout(5, false);
        radioPanel.setLayout(layout2);

        this.radioPresetHigh = new Button(radioPanel, SWT.RADIO);
        radioPresetHigh.setText(resources.getString("label.high"));
        radioPresetHigh.setLayoutData(new GridData());
        radioPresetHigh.addSelectionListener(new RadioListener());

        this.radioPresetMedium = new Button(radioPanel, SWT.RADIO);
        radioPresetMedium.setText(resources.getString("label.medium"));
        radioPresetMedium.setLayoutData(new GridData());
        radioPresetMedium.addSelectionListener(new RadioListener());

        this.radioPresetLow = new Button(radioPanel, SWT.RADIO);
        radioPresetLow.setText(resources.getString("label.low"));
        radioPresetLow.setLayoutData(new GridData());
        radioPresetLow.addSelectionListener(new RadioListener());

        this.radioPresetCustom = new Button(radioPanel, SWT.RADIO);
        radioPresetCustom.setText(resources.getString("label.custom"));
        radioPresetCustom.setLayoutData(new GridData());
        radioPresetCustom.addSelectionListener(new RadioListener());

        ScaleFieldEditor editorClutter =
            new ScaleFieldEditor(
                "clutterdistance",
                resources.getString("label.clutterdistance"),
                group);

        editorClutter.setMinimum(0);
        editorClutter.setMaximum(10000);
        editorClutter.setPageIncrement(1000);

        addField(editorClutter);

        ScaleFieldEditor editorVar =
            new ScaleFieldEditor(
                "varlevel",
                resources.getString("label.varlevel"),
                group);

        editorVar.setMinimum(250);
        editorVar.setMaximum(20000);
        editorVar.setPageIncrement(1975);

        addField(editorVar);

        ScaleFieldEditor editorLod =
            new ScaleFieldEditor(
                "aircraftlod",
                resources.getString("label.aircraftlod"),
                group);

        editorLod.setMinimum(0);
        editorLod.setMaximum(800);
        editorLod.setPageIncrement(80);

        addField(editorLod);

        ScaleFieldEditor editorRender =
            new ScaleFieldEditor(
                "minrender",
                resources.getString("label.minrender"),
                group);

        editorRender.setMinimum(0);
        editorRender.setMaximum(50000);
        editorRender.setPageIncrement(5000);

        addField(editorRender);

        RadioGroupFieldEditor editorGround =
            new RadioGroupFieldEditor(
                "grounddetail",
                resources.getString("label.grounddetail"),
                3,
                new String[][] {
                    new String[] {resources.getString("label.high"), "2"},
                    new String[] {resources.getString("label.medium"), "1"},
                    new String[] {resources.getString("label.low"), "0"},
                    },
                group);

        addField(editorGround);

        RadioGroupFieldEditor editorTexture =
            new RadioGroupFieldEditor(
                "texsize",
                resources.getString("label.texsize"),
                4,
                new String[][] {
                    new String[] {
                        resources.getString("label.unlimited"),
                        "0" },
                    new String[] {"512x512", "1"},
                    new String[] {"256x256", "2"},
                    new String[] {"128x128", "3"},
                    },
                group);

        addField(editorTexture);

        RadioGroupFieldEditor editorTerrain =
            new RadioGroupFieldEditor(
                "terraintexquality",
                resources.getString("label.terraintexquality"),
                4,
                new String[][] {
                    new String[] {"256x256", "256"},
                    new String[] {"128x128", "128"},
                    new String[] {"64x64", "64"},
                    },
                group);

        addField(editorTerrain);

        RadioGroupFieldEditor editorWater =
            new RadioGroupFieldEditor(
                "watermode",
                resources.getString("label.watermode"),
                4,
                new String[][] {
                    new String[] {
                        resources.getString("label.watermode.0"),
                        "0" },
                    new String[] {
                        resources.getString("label.watermode.1"),
                        "1" },
                    new String[] {
                        resources.getString("label.watermode.2"),
                        "2" },
                    },
                group);

        addField(editorWater);

        RadioGroupFieldEditor editorShadows =
            new RadioGroupFieldEditor(
                "shadows",
                resources.getString("label.shadows"),
                4,
                new String[][] {
                    new String[] {
                        resources.getString("label.shadows.2"),
                        "2" },
                    new String[] {
                        resources.getString("label.shadows.1"),
                        "1" },
                    new String[] {
                        resources.getString("label.shadows.0"),
                        "0" },
                    },
                group);

        addField(editorShadows);

        BooleanFieldEditor editorEnv =
            new BooleanFieldEditor(
                "envmap.boolean",
                resources.getString("label.envmap"),
                group);

        editorEnv.fillIntoGrid(group, 2);

        addField(editorEnv);

        BooleanFieldEditor editorMultipass =
            new BooleanFieldEditor(
                "multipass.boolean",
                resources.getString("label.multipass"),
                group);

        editorMultipass.fillIntoGrid(group, 2);

        addField(editorMultipass);

        GridLayout gridLayout = new GridLayout(2, false);
        gridLayout.marginWidth = 10;
        gridLayout.marginHeight = 10;

        group.setLayout(gridLayout);

        this.presetEditors = new FastArrayList(9);
        presetEditors.add((editorVar));
        presetEditors.add((editorLod));
        presetEditors.add((editorGround));
        presetEditors.add((editorTerrain));
        presetEditors.add((editorTexture));
        presetEditors.add((editorRender));
        presetEditors.add((editorEnv));
        presetEditors.add((editorWater));
        presetEditors.add((editorShadows));
        presetEditors.add((editorClutter));

        return panel;
    }

    private void setPresetSetting(final int preset) {
        IPreferenceStore preferences = getPreferenceStore();

        preferences.setValue("varlevel", PRESET_VAR[preset]);
        preferences.setValue("aircraftlod", PRESET_LOD[preset]);
        preferences.setValue("grounddetail", PRESET_DETAIL[preset]);
        preferences.setValue("texsize", PRESET_TEXSIZE[preset]);
        preferences.setValue("terraintexquality", PRESET_TEX[preset]);
        preferences.setValue("minrender", PRESET_RENDER[preset]);
        preferences.setValue("envmap.boolean", PRESET_EMAP[preset]);
        preferences.setValue("watermode", PRESET_WATER[preset]);
        preferences.setValue("shadows", PRESET_SHADOW[preset]);
        preferences.setValue("clutterdistance", PRESET_CLUTTER[preset]);

        Iterator it = presetEditors.iterator();
        while (it.hasNext()) {
            FieldEditor editor = (FieldEditor) it.next();
            editor.load();
        }

        performApply();
        getContainer().updateButtons();
    }

    private boolean isPresetSetting(final int preset) {
        IPreferenceStore preferences = getPreferenceStore();

        if (PRESET_VAR[preset] != preferences.getInt("varlevel")
            || PRESET_LOD[preset] != preferences.getInt("aircraftlod")
            || PRESET_DETAIL[preset] != preferences.getInt("grounddetail")
            || PRESET_TEXSIZE[preset] != preferences.getInt("texsize")
            || PRESET_TEX[preset] != preferences.getInt("terraintexquality")
            || PRESET_RENDER[preset] != preferences.getInt("minrender")
            || PRESET_EMAP[preset] != preferences.getBoolean("envmap.boolean")
            || PRESET_WATER[preset] != preferences.getInt("watermode")
            || PRESET_SHADOW[preset] != preferences.getInt("shadows")
            || PRESET_CLUTTER[preset] != preferences.getInt("clutterdistance")) {
            return false;
        }

        return true;
    }

    /**
     * @see org.eclipse.jface.util.IPropertyChangeListener#propertyChange(org.eclipse.jface.util.PropertyChangeEvent)
     */
    public void propertyChange(final PropertyChangeEvent event) {
        super.propertyChange(event);
        checkPresetSettings();
    }


    /**
     * @see org.wbconfig.widget.ConfigurationTab#performLoad()
     */
    public void performLoad() {
        super.performLoad();
        checkPresetSettings();
    }

    private void checkPresetSettings() {
        radioPresetHigh.setSelection(isPresetSetting(PRESET_HIGH));
        radioPresetMedium.setSelection(isPresetSetting(PRESET_MEDIUM));
        radioPresetLow.setSelection(isPresetSetting(PRESET_LOW));

        boolean isCustom =
            !radioPresetHigh.getSelection()
                && !radioPresetMedium.getSelection()
                && !radioPresetLow.getSelection();

        radioPresetCustom.setSelection(isCustom);
    }

    private class RadioListener implements SelectionListener {
        public void widgetSelected(final SelectionEvent event) {
            Button button = (Button) event.widget;
            if (button.getSelection()) {
                if (event.widget == radioPresetHigh) {
                    setPresetSetting(PRESET_HIGH);
                } else {
                    radioPresetHigh.setSelection(false);
                }

                if (event.widget == radioPresetMedium) {
                    setPresetSetting(PRESET_MEDIUM);
                } else {
                    radioPresetMedium.setSelection(false);
                }

                if (event.widget == radioPresetLow) {
                    setPresetSetting(PRESET_LOW);
                } else {
                    radioPresetLow.setSelection(false);
                }

                if (event.widget != radioPresetCustom) {
                    radioPresetCustom.setSelection(false);
                }
            }
        }

        public void widgetDefaultSelected(final SelectionEvent event) {
        }
    }
}