package org.wbconfig.widget;

import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.IntegerFieldEditor;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.wbconfig.resource.ResourceManager;

/**
 * FlightTab.java
 *
 * @author Xavier Cho
 * @version $Revision: 1.5 $ $Date: 2004/01/18 14:47:43 $
 */
public class FlightTab extends ConfigurationTab {
    public FlightTab() {
    }

    /**
     * @param title
     */
    public FlightTab(final String title) {
        super(title);
    }

    /**
     * @param title
     * @param image
     */
    public FlightTab(final String title, final ImageDescriptor image) {
        super(title, image);
    }

    /**
     * @see org.eclipse.jface.preference.PreferencePage#createContents(org.eclipse.swt.widgets.Composite)
     */
    protected Control createContents(final Composite parent) {
        Composite panel = new Composite(parent, SWT.NULL);

        GridLayout layout = new GridLayout(1, false);
        layout.marginWidth = 10;
        layout.marginHeight = 10;

        panel.setLayout(layout);

        ResourceManager resources = ResourceManager.getInstance();

        Group group = new Group(panel, SWT.NULL);
        group.setText(resources.getString("group.flight"));
        group.setLayoutData(new GridData(GridData.FILL_BOTH));

        IntegerFieldEditor editorSpeed =
            new IntegerFieldEditor(
                "speed",
                resources.getString("label.speed"),
                group);

        editorSpeed.setValidRange(0, 10000);

        addField(editorSpeed);

        GridData data = new GridData();
        data.widthHint = 150;
        editorSpeed.getTextControl(group).setLayoutData(data);

        IntegerFieldEditor editorSalvo =
            new IntegerFieldEditor(
                "salvo",
                resources.getString("label.salvo"),
                group);

        editorSalvo.setValidRange(0, 100);

        addField(editorSalvo);

        GridData data2 = new GridData();
        data2.widthHint = 150;
        editorSalvo.getTextControl(group).setLayoutData(data2);

        IntegerFieldEditor editorDelay =
            new IntegerFieldEditor(
                "delay",
                resources.getString("label.delay"),
                group);

        editorDelay.setValidRange(0, 10000);

        GridData data3 = new GridData();
        data3.widthHint = 150;
        editorDelay.getTextControl(group).setLayoutData(data3);

        addField(editorDelay);

        BooleanFieldEditor editorHUD =
            new BooleanFieldEditor(
                "hud.boolean",
                resources.getString("label.hud"),
                group);

        editorHUD.fillIntoGrid(group, 2);

        addField(editorHUD);

        BooleanFieldEditor editorSlip =
            new BooleanFieldEditor(
                "slip.boolean",
                resources.getString("label.slip"),
                group);

        editorSlip.fillIntoGrid(group, 2);

        addField(editorSlip);

        BooleanFieldEditor editorSmoke =
            new BooleanFieldEditor(
                "smoke.boolean",
                resources.getString("label.smoke"),
                group);

        editorSmoke.fillIntoGrid(group, 2);

        addField(editorSmoke);

        GridLayout gridLayout2 = new GridLayout(2, false);
        gridLayout2.marginWidth = 10;
        gridLayout2.marginHeight = 10;

        group.setLayout(gridLayout2);

        return panel;
    }
}