package org.wbconfig.widget;

import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.IntegerFieldEditor;
import org.eclipse.jface.preference.RadioGroupFieldEditor;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.wbconfig.resource.ResourceManager;

/**
 * GeneralTab.java
 *
 * @author Xavier Cho
 * @version $Revision: 1.5 $ $Date: 2004/01/18 11:51:28 $
 */
public class GeneralTab extends ConfigurationTab {

    public GeneralTab() {
    }

    /**
     * @param title
     */
    public GeneralTab(final String title) {
        super(title);
    }

    /**
     * @param title
     * @param image
     */
    public GeneralTab(final String title, final ImageDescriptor image) {
        super(title, image);
    }

    /**
     * @see org.eclipse.jface.preference.PreferencePage#createContents(org.eclipse.swt.widgets.Composite)
     */
    protected Control createContents(final Composite parent) {
        Composite panel = new Composite(parent, SWT.NULL);

        GridLayout layout = new GridLayout(1, false);
        layout.marginWidth = 10;
        layout.marginHeight = 10;

        panel.setLayout(layout);

        ResourceManager resources = ResourceManager.getInstance();

        Group groupRadio = new Group(panel, SWT.NULL);
        groupRadio.setText(resources.getString("group.radio"));
        groupRadio.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));

        RadioGroupFieldEditor editorFont =
            new RadioGroupFieldEditor(
                "fontsize",
                resources.getString("label.fontsize"),
                4,
                new String[][] {
                    new String[] {resources.getString("label.large"), "2"},
                    new String[] {resources.getString("label.medium"), "1"},
                    new String[] {resources.getString("label.small"), "0"},
                    },
                groupRadio);

        addField(editorFont);

        IntegerFieldEditor editorRadioW =
            new IntegerFieldEditor(
                "radiowidth",
                resources.getString("label.radiowidth"),
                groupRadio);

        editorRadioW.setValidRange(1, 2000);

        GridData data = new GridData();
        data.widthHint = 150;
        editorRadioW.getTextControl(groupRadio).setLayoutData(data);

        addField(editorRadioW);

        IntegerFieldEditor editorRadioH =
            new IntegerFieldEditor(
                "radiolines",
                resources.getString("label.radiolines"),
                groupRadio);

        editorRadioH.setValidRange(1, 30);

        GridData data2 = new GridData();
        data2.widthHint = 150;
        editorRadioH.getTextControl(groupRadio).setLayoutData(data2);

        addField(editorRadioH);

        GridLayout gridLayout = new GridLayout(2, false);
        gridLayout.marginWidth = 10;
        gridLayout.marginHeight = 10;

        groupRadio.setLayout(gridLayout);

        Group groupMisc = new Group(panel, SWT.NULL);
        groupMisc.setText(resources.getString("group.misc"));
        groupMisc.setLayoutData(new GridData(GridData.FILL_BOTH));

        BooleanFieldEditor editorHls =
            new BooleanFieldEditor(
                "hls.toggle",
                resources.getString("label.hls"),
                groupMisc);

        editorHls.fillIntoGrid(groupMisc, 2);

        addField(editorHls);

        BooleanFieldEditor editorLB =
            new BooleanFieldEditor(
                "lindablair.toggle",
                resources.getString("label.lindablair"),
                groupMisc);

        editorLB.fillIntoGrid(groupMisc, 2);

        addField(editorLB);

        BooleanFieldEditor editorFPS =
            new BooleanFieldEditor(
                "framemode",
                resources.getString("label.framemode"),
                groupMisc);

        editorFPS.fillIntoGrid(groupMisc, 2);

        addField(editorFPS);

        BooleanFieldEditor editorLabels =
            new BooleanFieldEditor(
                "grndlabels.toggle",
                resources.getString("label.grndlabels"),
                groupMisc);

        editorLabels.fillIntoGrid(groupMisc, 2);

        addField(editorLabels);

        GridLayout gridLayout2 = new GridLayout(2, false);
        gridLayout2.marginWidth = 10;
        gridLayout2.marginHeight = 10;

        groupMisc.setLayout(gridLayout2);

        return panel;
    }
}