package org.wbconfig.widget;

import java.util.MissingResourceException;
import java.util.ResourceBundle;
import java.util.StringTokenizer;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.FieldEditor;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.TabFolder;
import org.eclipse.swt.widgets.TabItem;
import org.wbconfig.resource.ResourceManager;

/**
 * PreloadTab.java
 *
 * @author Xavier Cho
 * @version $Revision: 1.9 $ $Date: 2004/01/24 14:25:14 $
 */
public class PreloadTab extends ConfigurationTab {
    private ResourceBundle planes;
    private TabFolder tabFolder;

    public PreloadTab() {
    }

    /**
     * @param title
     */
    public PreloadTab(final String title) {
        super(title);
    }

    /**
     * @param title
     * @param image
     */
    public PreloadTab(final String title, final ImageDescriptor image) {
        super(title, image);
    }

    /**
     * @see org.eclipse.jface.preference.PreferencePage#createContents(org.eclipse.swt.widgets.Composite)
     */
    protected Control createContents(final Composite parent) {
        Composite panel = new Composite(parent, SWT.NULL);

        FillLayout layout = new FillLayout();
        layout.marginWidth = 10;
        layout.marginHeight = 10;

        panel.setLayout(layout);

        this.planes = ResourceBundle.getBundle("org.wbconfig.resource.Preload");
        this.tabFolder = new TabFolder(panel, SWT.BORDER);

        addTab("Axis");
        addTab("Japanese");
        addTab("Allies");
        addTab("GV");

        return panel;
    }

    private void addTab(final String groupName) {
        ResourceManager resources = ResourceManager.getInstance();
        String resourceKey = "preload." + groupName;

        TabItem item = new TabItem(tabFolder, SWT.NULL);
        item.setText(resources.getString(resourceKey));

        Composite panel = new Composite(tabFolder, SWT.NULL);
        panel.setLayout(new GridLayout(1, false));

        Composite upperPanel = new Composite(panel, SWT.NULL);
        upperPanel.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));

        String values = planes.getString(resourceKey);
        StringTokenizer tokenizer = new StringTokenizer(values, ",");

        while (tokenizer.hasMoreTokens()) {
            String value = (String) tokenizer.nextToken();
            String key = "preload." + value;

            try {
                String name = planes.getString(key);
                FieldEditor editor =
                    new BooleanFieldEditor(key, name, upperPanel);

                addField(editor);
            } catch (MissingResourceException e) {
                Log log = LogFactory.getLog(PreloadTab.class);

                if (log.isWarnEnabled()) {
                    String msg = "Unknown preload number : " + key;
                    log.warn(msg);
                }
            }
        }

        GridLayout layout = new GridLayout(4, true);
        layout.marginWidth = 5;
        layout.marginHeight = 5;

        upperPanel.setLayout(layout);

        Composite lowerPanel = new Composite(panel, SWT.NULL);

        FillLayout fillLayout = new FillLayout(SWT.HORIZONTAL);
        fillLayout.spacing = 3;

        lowerPanel.setLayout(fillLayout);

        GridData data = new GridData();
        data.grabExcessVerticalSpace = true;
        data.verticalAlignment = GridData.END;

        lowerPanel.setLayoutData(data);

        Button buttonAll = new Button(lowerPanel, SWT.BORDER);
        buttonAll.setText(resources.getString("button.select.all"));
        buttonAll.addSelectionListener(new ButtonSelector(upperPanel, true));

        Button buttonNone = new Button(lowerPanel, SWT.BORDER);
        buttonNone.setText(resources.getString("button.clear"));
        buttonNone.addSelectionListener(new ButtonSelector(upperPanel, false));

        item.setControl(panel);
    }

    private final class ButtonSelector implements SelectionListener {
        private Composite parent;
        private boolean selected = true;

        private ButtonSelector(
            final Composite parent,
            final boolean selected) {
            this.parent = parent;
            this.selected = selected;
        }

        public void widgetSelected(final SelectionEvent event) {
            Control[] controls = parent.getChildren();
            int count = controls.length;
            for (int i = 0; i < count; i++) {
                Control control = controls[i];
                if (control instanceof Button
                    && !control.equals(event.widget)) {
                    Button button = (Button) control;
                    button.setSelection(selected);
                }
            }

            performApply();
            getContainer().updateButtons();
        }

        public void widgetDefaultSelected(final SelectionEvent event) {
        }
    }
}