package org.wbconfig.widget;

import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Shell;
import org.wbconfig.preference.ConfigPreferenceStore;
import org.wbconfig.resource.ResourceManager;
import org.wbconfig.util.ExceptionHandler;

/**
 * PreviewDialog.java
 *
 * @author Xavier Cho
 * @version $Revision: 1.1 $ $Date: 2004/01/31 06:07:53 $
 */
public class PreviewDialog extends Dialog {

    /**
     * @param shell
     */
    public PreviewDialog(final Shell parent) {
        super(parent);
    }

    /**
     * @see org.eclipse.jface.dialogs.Dialog#createButtonsForButtonBar(org.eclipse.swt.widgets.Composite)
     */
    protected void createButtonsForButtonBar(final Composite parent) {
        createButton(
            parent,
            IDialogConstants.OK_ID,
            IDialogConstants.CLOSE_LABEL,
            true);
    }

    /**
     * @see org.eclipse.jface.dialogs.Dialog#createDialogArea(org.eclipse.swt.widgets.Composite)
     */
    protected Control createDialogArea(final Composite parent) {
        Composite panel = (Composite) super.createDialogArea(parent);

        ResourceManager resources = ResourceManager.getInstance();

        FillLayout fillLayout = new FillLayout();
        fillLayout.marginWidth = 10;
        fillLayout.marginHeight = 5;

        panel.setLayout(fillLayout);

        FillLayout fillLayout2 = new FillLayout();
        fillLayout2.marginWidth = 10;
        fillLayout2.marginHeight = 10;

        Group group = new Group(panel, SWT.NULL);
        group.setText(resources.getString("group.preview"));
        group.setLayout(fillLayout2);

        StyledText editor =
            new StyledText(
                group, SWT.BORDER | SWT.V_SCROLL | SWT.READ_ONLY);

        StringWriter writer = new StringWriter();

        try {
            ConfigPreferenceStore preferences =
                ConfigPreferenceStore.getInstance();
            preferences.list(new PrintWriter(writer));

            writer.close();

            editor.setText(writer.toString());
        } catch (IOException e) {
            String msg = resources.getString("error.message.preview");
            ExceptionHandler.handleException(msg, e);
        }

        return panel;
    }

    /**
     * @see org.eclipse.jface.window.Window#getInitialSize()
     */
    protected Point getInitialSize() {
        return new Point(640, 480);
    }
}
